# ocm2


[![image](https://img.shields.io/pypi/v/ocm2.svg)](https://pypi.python.org/pypi/ocm2)
[![image](https://img.shields.io/conda/vn/conda-forge/ocm2.svg)](https://anaconda.org/conda-forge/ocm2)


**This python package extracts subdatasets from OCM-2 HDF file, georeference them and exports them to GeoTIFF. The package also creates a cloud mask layer.**


-   Free software: MIT license
-   Documentation: https://akhi9661.github.io/ocm2
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
